
clear 

**INDSTAT2**
*add variable descriptions and labels*
insheet ctable country year isic isiccomb value utable source unit using "$dir\data\unido\unido_2digit\data_indstat2.csv", comma nonames clear
label variable ctable "Table Code"
label define ctable 01 "Number of establishments" 04 "Employment" 05 "Wages and salaries (at current prices)" ///
14 "Output (at current prices)" 20 "Value added (at current prices)" 21 "Gross fixed capital formation (at current prices)" ///
31 "Number of female employees" 51 "Index numbers of industrial production"
label value ctable ctable
label variable country "Country numeric code"
label variable year "Year"
label variable isic "ISIC Code"
label define isic 15 "Food and beverages" 16 "Tobacco products" 17 "Textiles" 18 "Wearing apparel, fur" ///
19 "Leather, leather products and footwear" 20 "Wood products (excluding furniture)" 21 "Paper and paper products" ///
22 "Printing and publishing" 23 "Coke, refined petroleum products, nuclear fuel" 24 "Chemicals and chemical products" ///
25 "Rubber and plastics products" 26 "Non-metallic mineral products" 27 "Basic metals" 28 "Fabricated metal products" ///
29 "Machinery and equipment n.e.c." 30 "Office, accounting and computing machinery" 31 "Electrical machinery and apparatus" /// 
32 "Radio, television and communication equipment" 33 "Medical, precision and optical instruments" ///
34 "Motor vehicles, trailers, semi-trailers" 35 "Other transport equipment" 36 "Furniture; manufacturing n.e.c." ///
37 "Recycling"
label value isic isic
label variable isiccomb "ISIC Combination Code"
label variable value "Value"
label variable utable "Table Definition code"
label define utable 01"Number of establishments" 02"Number of enterprises" 03"Number of persons engaged" ///
04"Number of employees" 05"Wages and salaries paid to employees" 11"Output at basic prices " 12"Output at factor values" ///
13"Output at producers' prices" 14"Output (valuation not defined)" 17"Value added at basic prices" 18"Value added at factor values" ///
19"Value added at producers' prices" 20"Value added (valuation not defined)" 21"Gross fixed capital formation" ///
31"Number of female employees" 51"Index numbers of industrial production"
label value utable utable
label variable source "Source Code"
labe define source 1 "Data: (a) collected by UNIDO from national sources; (b) compiled by OECD and provided to UNIDO; (c) derived from UNSD with respect to index numbers of industrial production." ///
2 "Data: (a) generated/adjusted by UNIDO based on national sources, regional publications including official websites; and, (b) aggregated from complete set of available 3-/4-digit sub-sectors." ///
3 "Data generated/adjusted by UNIDO based on: (a) converted data from ISIC Rev.2; (b) aggregated data from incomplete set of ISIC Rev.3 3-and 4-digit sub-sectors; (c) converted data from ISIC Rev.4; and, (d) UNIDO estimates." ///
4 "UNIDO estimates." 5 "UNIDO estimates."
label value source source
label variable unit "Unit:#= number, N= value in current national currency, $= value in current US Dollars, I= index value"
destring value, replace ignore(".")
*add country iso character code*
kountry country, from(iso3n) to(iso3c) 
rename country iso3n
rename _ISO3C_ iso3c
tab iso3n if iso3c==""
replace iso3c="TWN" if iso3n==158 
replace iso3c="CZS" if iso3n==200 
replace iso3c="ETH1" if iso3n==230 /* Ethiopia and Eriteria*/
replace iso3c="GFR" if iso3n==280 
replace iso3c="GDR" if iso3n==278 
replace iso3c="MNE" if iso3n==499
replace iso3c="CUW" if iso3n==531 
replace iso3c="PAN" if iso3n==590 
replace iso3c="RUS" if iso3n==643 
replace iso3c="USSR" if iso3n==810 
replace iso3c="SRB" if iso3n==688 
replace iso3c="TZA" if iso3n==834
replace iso3c="YUG" if iso3n==890
replace iso3c="SCG" if iso3n==891
tab iso3n if iso3c==""
drop if iso3c=="CZS" & year==1991
drop if iso3c=="CZE" & year>=1980 & year<=1990 /*repeated observations for Czechoslovakia, Czechia and Slovakia*/
order iso3n iso3c year isic isiccomb
save "$dir/data/unido/unido_2digit/unido2.dta", replace
*reshape dataset*
use "$dir/data/unido/unido_2digit/unido2.dta", clear
keep if ctable==4
rename value employment
label variable employment "Employment"
rename utable employment_desc
save "$dir/data/unido/unido_2digit/employment.dta", replace

use "$dir/data/unido/unido_2digit/unido2.dta", clear
keep if ctable==20
rename value value_added 
label variable value_added "Value added "
rename utable value_added_desc
save "$dir/data/unido/unido_2digit/value_added.dta", replace

use "$dir/data/unido/unido_2digit/employment.dta", clear
drop ctable source unit isiccomb
merge 1:1 iso3n year isic using  "$dir/data/unido/unido_2digit/value_added.dta"
drop ctable source unit isiccomb _merge
save "$dir/data/unido/unido_2digit/unido2_allvar.dta", replace
*balance dataset (Cadot et al., 2011)*
use "$dir/data/unido/unido_2digit/unido2_allvar.dta", clear
keep iso3c year isic employment value_added
replace employment=0 if employment<0 | employment==.
replace value_added=0 if value_added<0 | value_added==. /* employement and value_added can't be negative*/
sort iso3c year isic
save "$dir/data/unido/unido_2digit/unido2_final.dta", replace
*calculate gini for employment*
use "$dir/data/unido/unido_2digit/unido2_final.dta",clear 
keep iso3c year isic employment
sort year iso3c employment
bysort year iso3c: egen total_emp=total(employment)
drop if total_emp==0 /*missing observations*/
by year iso3c: gen si_emp= sum(employment/total_emp)
egen y_emp = sum((si_emp+si_emp[_n-1])/23), by (year iso3c)
by year iso3c: gen gini_emp= abs(1-y_emp)
*calculate hhi for employment*
by year iso3c: gen si2 = (employment/total_emp)^2
egen hhi =sum(si2), by (year iso3c)
gen hhi_emp= (hhi-(1/23)) / (1-(1/23))
collapse (sum) employment (mean) gini_emp hhi_emp, by (iso3c year)
save "$dir/data/unido/unido_2digit/gini_emp.dta", replace
*calculate gini for value_added*
use "$dir/data/unido/unido_2digit/unido2_final.dta",clear 
keep iso3c year isic value_added 
sort year iso3c value_added
bysort year iso3c: egen total_va=total(value_added)
drop if total_va==0 /*missing observations*/
by year iso3c: gen si_va= sum(value_added/total_va)
egen y_va = sum((si_va+si_va[_n-1])/23), by (year iso3c)
by year iso3c: gen gini_va= abs(1-y_va)
*calculate hhi*
by year iso3c: gen si2_va = (value_added/total_va)^2
egen hhi=sum(si2), by (year iso3c)
gen hhi_va= (hhi-(1/23)) / (1-(1/23))
collapse (sum) value_added (mean) gini_va hhi_va, by (iso3c year)
save "$dir/data/unido/unido_2digit/gini_va.dta", replace
*merge gini for employement and value-added*
merge 1:1 iso3c year using "$dir/data/unido/unido_2digit/gini_emp.dta"
drop _merge
order iso3c year employment gini_emp hhi_emp value_added gini_va hhi_va 
save "$dir/data/unido/unido_2digit/diversification.dta", replace

**INDSTAT4: 4 digit**
*add variable descriptions and labels*
use "$dir/data/unido/unido_4digit/data.dta", clear
drop if ISIC=="D"
destring TableCode CountryCode Year ISIC TableDefinitionCode , replace
destring Value, replace ignore(".")
rename TableCode ctable
rename CountryCode iso3n
label variable iso3n "Country numeric code"
rename Year year
label variable year "Year"
rename ISIC isic
label variable isic "ISIC Code"
rename ISICCombination isiccomb
label variable isiccomb "ISIC Combination Code"
rename Value value
label variable value "Value"
rename TableDefinitionCode utable
label variable utable "Table Definition code"
rename K table_desc
rename SourceCode source
label variable source "Source Code"
rename Unit unit
label variable unit "Unit:#= number, N= value in current national currency, $= value in current US Dollars, I= index value"
labmask ctable, values(TableDescription)
labmask iso3n, values(CountryDescription)
labmask isic, values(ISICDescription)
labmask utable, values(table_desc)
labe define source 1 "Data: (a) collected by UNIDO from national sources; (b) compiled by OECD and provided to UNIDO; (c) derived from UNSD with respect to index numbers of industrial production." ///
2 "Data: (a) generated/adjusted by UNIDO based on national sources, regional publications including official websites; and, (b) aggregated from complete set of available 3-/4-digit sub-sectors." ///
3 "Data generated/adjusted by UNIDO based on: (a) converted data from ISIC Rev.2; (b) aggregated data from incomplete set of ISIC Rev.3 3-and 4-digit sub-sectors; (c) converted data from ISIC Rev.4; and, (d) UNIDO estimates." ///
4 "UNIDO estimates." 5 "UNIDO estimates."
label value source source
drop TableDescription CountryDescription ISICDescription table_desc
save "$dir/data/unido/unido_4digit/unido4.dta", replace
*reshape dataset*
use "$dir/data/unido/unido_4digit/unido4.dta", clear
keep if ctable==4
rename value employment
label variable employment "Employment"
rename utable employment_desc
save "$dir/data/unido/unido_4digit\employment.dta", replace

use "$dir/data/unido/unido_4digit/unido4.dta", clear
keep if ctable==20
rename value value_added 
label variable value_added "Value added "
rename utable value_added_desc
save "$dir/data/unido/unido_4digit\value_added.dta", replace

use "$dir/data/unido/unido_4digit\employment.dta", clear
drop ctable source unit isiccomb
merge 1:1 iso3n year isic using "$dir/data/unido/unido_4digit/value_added.dta"
drop ctable source unit isiccomb _merge
save "$dir/data/unido/unido_4digit\unido4_allvar.dta", replace
*balance dataset (as Cadot et al., 2011)*
use "$dir/data/unido/unido_4digit\unido4_allvar.dta", clear
keep iso3n year isic employment value_added
replace employment=0 if employment<0 | employment==.
replace value_added=0 if value_added<0 | value_added==. /* employement and value_added can't be negative*/
*add country iso character code *
kountry iso3n, from(iso3n) to(iso3c) 
rename _ISO3C_ iso3c
tab iso3n if iso3c==""
replace iso3c="TWN" if iso3n==158 
replace iso3c="CUW" if iso3n==531 
replace iso3c="PAN" if iso3n==590 
replace iso3c="RUS" if iso3n==643 
replace iso3c="SRB" if iso3n==688 
replace iso3c="TZA" if iso3n==834 
replace iso3c="SCG" if iso3c=="SRB" & year<2003
replace iso3n=891 if iso3n==688 & year<2003
save "$dir/data/unido/unido_4digit\unido4_final.dta", replace
*calculate gini for employment*
use "$dir/data/unido/unido_4digit\unido4_final.dta",clear 
keep iso3c year isic employment 
sort year iso3c employment
bysort year iso3c: egen total_emp=total(employment)
drop if total_emp==0 /*missing observations*/ 
by year iso3c: gen si_emp= sum(employment/total_emp)
egen y_emp = sum((si_emp+si_emp[_n-1])/127), by (year iso3c)
by year iso3c: gen gini_emp= abs(1-y_emp)
*calculate hhi for employment*
by year iso3c: gen si2 = (employment/total_emp)^2
egen hhi =sum(si2), by (year iso3c)
gen hhi_emp= (hhi-(1/127)) / (1-(1/127))
collapse (sum) employment (mean) gini_emp hhi_emp, by (iso3c year)
save "$dir/data/unido/unido_4digit\gini_emp.dta", replace
*calculate gini for value_added*
use "$dir/data/unido/unido_4digit\unido4_final.dta",clear 
keep iso3c year isic value_added
sort year iso3c value_added
bysort year iso3c: egen total_va=total(value_added)
drop if total_va==0 /*missing observations*/
by year iso3c: gen si_va= sum(value_added/total_va)
egen y_va = sum((si_va+si_va[_n-1])/127), by (year iso3c)
by year iso3c: gen gini_va= abs(1-y_va)
*calculate hhi*
by year iso3c: gen si2_va = (value_added/total_va)^2
egen hhi=sum(si2), by (year iso3c)
gen hhi_va= (hhi-(1/127)) / (1-(1/127))
collapse (sum) value_added (mean) gini_va hhi_va, by (iso3c year)
save "$dir/data/unido/unido_4digit/gini_va.dta", replace

merge 1:1 iso3c year using "$dir/data/unido/unido_4digit\gini_emp.dta"
drop _merge
sort iso3c year
order iso3c year employment gini_emp hhi_emp value_added gini_va hhi_va 
save "$dir/data/unido/unido_4digit/diversification.dta", replace

**INDSTAT4: 3-digit**
use "$dir\data\unido\unido_4digit\unido4_final.dta", clear
gen isic_3=int(isic/10)
collapse (sum) employment value_added, by (iso3c year isic_3)
rename isic_3 isic
save "$dir\data\unido\unido_3digit/unido3_final.dta", replace
*calculate gini for employment*
use "$dir\data\unido\unido_3digit/unido3_final.dta", clear 
sort year iso3c iso3c employment
bysort year iso3c: egen total_emp=total(employment)
drop if total_emp==0 /*missing observations*/
by year iso3c: gen si_emp= sum(employment/total_emp)
egen y_emp = sum((si_emp+si_emp[_n-1])/61), by (year iso3c)
by year iso3c: gen gini_emp= abs(1-y_emp)
*calculate hhi for employment*
by year iso3c: gen si2 = (employment/total_emp)^2
egen hhi =sum(si2), by (year iso3c)
gen hhi_emp= (hhi-(1/61)) / (1-(1/61))
collapse (sum) employment (mean) gini_emp hhi_emp, by (iso3c year)
save "$dir\data\unido\unido_3digit/gini_emp.dta", replace
*calculate gini for value_added*
use "$dir\data\unido\unido_3digit/unido3_final.dta", clear 
sort year iso3c value_added
bysort year iso3c: egen total_va=total(value_added)
drop if total_va==0 /*missing observations*/
by year iso3c: gen si_va= sum(value_added/total_va)
egen y_va = sum((si_va+si_va[_n-1])/61), by (year iso3c)
by year iso3c: gen gini_va= abs(1-y_va)
*calculate hhi*
by year iso3c: gen si2_va = (value_added/total_va)^2
egen hhi=sum(si2), by (year iso3c)
gen hhi_va= (hhi-(1/61)) / (1-(1/61))
collapse (sum) value_added (mean) gini_va hhi_va , by (iso3c year)
save "$dir\data\unido\unido_3digit/gini_va.dta", replace

merge 1:1 iso3c year using "$dir\data\unido\unido_3digit/gini_emp.dta"
drop _merge
order iso3c year employment gini_emp hhi_emp value_added gini_va hhi_va 
save "$dir\data\unido\unido_3digit/diversification.dta", replace

**COMTRADE data**
*gini for export 4 digit*
use "$dir\data\comtrade/comtrade.dta", clear
keep iso year sitccode exportvalue
sort year iso exportvalue
bysort year iso: egen total_exp=total(exportvalue)
drop if total_exp==0 /*missing observations*/
by year iso: gen si_exp= sum(exportvalue/total_exp)
egen y_exp = sum((si_exp+si_exp[_n-1])/625), by (year iso)
by year iso: gen gini_exp_4= abs(1-y_exp)
*calculate hhi for exportvalue*
by year iso: gen si2 = (exportvalue/total_exp)^2
egen hhi =sum(si2), by (year iso)
gen hhi_exp_4= (hhi-(1/625)) / (1-(1/625))
collapse (sum) exportvalue (mean) gini_exp_4 hhi_exp_4, by (iso year)
rename iso iso3c
rename exportvalue exportvalue_4
save "$dir\data\comtrade/gini_exp_4.dta", replace

*gini for export 2 digit*
use "$dir\data\comtrade/comtrade.dta", clear
collapse (sum) exportvalue, by (iso year sitc_2digit)
sort year iso exportvalue
bysort year iso: egen total_exp=total(exportvalue)
drop if total_exp==0 /*missing observations*/
by year iso: gen si_exp= sum(exportvalue/total_exp)
egen y_exp = sum((si_exp+si_exp[_n-1])/61), by (year iso)
by year iso: gen gini_exp_2= abs(1-y_exp)
*calculate hhi for exportvalue*
by year iso: gen si2 = (exportvalue/total_exp)^2
egen hhi =sum(si2), by (year iso)
gen hhi_exp_2= (hhi-(1/61)) / (1-(1/61))
collapse (sum) exportvalue (mean) gini_exp_2 hhi_exp_2, by (iso year)
rename iso iso3c
rename exportvalue exportvalue_2
save "$dir\data\comtrade/gini_exp_2.dta", replace

merge 1:1 year iso3c using "$dir\data\comtrade/gini_exp_4.dta"
drop _merge 
save "$dir\data\comtrade/gini_comtrade.dta",replace

**GDP**			
*merge gdp and population*
use "$dir\data\gdp/population.dta", clear /*from WDI*/
merge 1:1 iso3c year using "$dir\data\gdp/gdppc.dta" /*from WDI*/
drop _merge
merge 1:1 iso3c year using "$dir\data\gdp/gdppc_penn.dta" /*from penn world table*/
drop _merge
*countries splitting / merging*
replace iso3c="CZS" if iso3c=="CZE" & year<=1990 /*income data on Zzech republic before 1991 assigned to Czechoslovakia*/
replace iso3c="ETH1" if iso3c=="ETH" & year>=1981 & year<=1989 /* income data for Ethipioa from 1981 to 1989, assigned to ETH1 (Ethipia and Eriteria)*/
replace iso3c="GFR" if iso3c=="DEU" & year<=1990 /* income data for Germany available from 1960 to 1990, assigned to GFR. no income data for East Germany*/
replace iso3c="YUG" if iso3c=="SRB" & year<=1990 /*income data for Serbia available from 1991 to 2002 assigned to SCG (Serbia and Montenegro) */
replace iso3c="SCG" if iso3c=="SRB" & year>=1991 & year<=2002
replace iso3c="USSR" if iso3c=="RUS" & year<=1992 /*income data on Russia before 1993 assigned to USSR*/
merge m:1 iso3c using "$dir\data\gdp/WB_classification.dta" /*from world bank*/
drop _merge
*convert 2017 $ to 1985 $*
merge 1:1 iso3c year using "$dir\data\gdp/gdppc_penn_1985.dta" /*from penn world table*/
drop if _merge==2 
drop _merge
gen penn_to_85= gdppc_penn / (107.025/54.030)  /* 2017 USD value / [US implicit gdp deflator in 2017/US implicit gdp deflator in 1985] = 1985 USD value(9637)) */
save "$dir\data\gdp/income.dta", replace

**Resource Abundance**
*working age population*
import excel "$dir\data\resources/pop.xlsx", sheet("Data") firstrow clear
rename *, lower
keep if seriescode=="SP.POP.1564.TO"
drop seriesname seriescode   
reshape long yr, i(countrycode) j(year)
rename yr workingpop
label var workingpop "Population ages 15-64, total (WDI)"
replace workingpop="." if workingpop==".."
destring workingpop, replace
codebook /* 2,564/16,226 missing*/
save "$dir\data\resources/workingpop.dta" , replace
*exports and imports* 
import excel "$dir\data\resources/resources.xlsx", sheet("data") firstrow clear
rename *, lower
drop seriescode
drop if seriesname=="" /*empty rows*/
reshape long yr, i (countryname countrycode seriesname) j(year) /*reshape data to long*/
encode seriesname, generate(seriescode)
labmask seriescode, values(seriesname)
drop seriesname
tab seriescode
tab seriescode, nolabel
reshape wide yr, i (countryname countrycode year) j(seriescode) /*reshape data to wide*/
rename yr1 fuelexports_share
label var fuelexports_share "Fuel exports (% of merchandise exports) (WDI)"
replace fuelexports_share="." if fuelexports_share==".."
destring fuelexports_share, replace
rename yr2 fuelimports_share
label var fuelimports_share "Fuel imports (% of merchandise imports) (WDI)"
replace fuelimports_share="." if fuelimports_share==".."
destring fuelimports_share, replace
rename yr3 exports
label var exports "Merchandise exports (current US$) (WDI)"
replace exports="." if exports==".."
destring exports, replace
rename yr4 imports
label var imports "Merchandise imports (current US$) (WDI)"
replace imports="." if imports==".."
destring imports, replace
rename yr5 metalexports_share
label var metalexports_share "Ores and metals exports (% of merchandise exports) (WDI)"
replace metalexports_share="." if metalexports_share==".."
destring metalexports_share, replace
rename yr6 metalimports_share
label var metalimports_share "Ores and metals imports (% of merchandise imports) (WDI)"
replace metalimports_share="." if metalimports_share==".."
destring metalimports_share, replace
**merge data**
merge 1:1 countryname countrycode year using "$dir\data\resources/workingpop.dta"
drop _merge
rename (countrycode countryname) (iso3c country)
**clean merged data**
*drop non countries*
drop if iso3c=="AFE"|iso3c=="AFW"|iso3c=="ARB"|iso3c=="CEB"|iso3c=="CSS"|iso3c=="EAP"| ///
iso3c=="EAR"|iso3c=="EAS"|iso3c=="ECA"|iso3c=="ECS"| iso3c=="EMU"|iso3c=="EUU"|iso3c=="FCS"| ///
iso3c=="HIC"|iso3c=="HPC"|iso3c=="IBD"|iso3c=="IBT"|iso3c=="IDA"|iso3c=="IDB"|iso3c=="IDX"| /// 
iso3c=="INX"|iso3c=="LAC"|iso3c=="LCN"|iso3c=="LDC"|iso3c=="LIC"|iso3c=="LMC"|iso3c=="LMY"| ///
iso3c=="LTE"|iso3c=="MEA"|iso3c=="MIC"|iso3c=="MNA"|iso3c=="NAC"|iso3c=="OED"|iso3c=="OSS"| ///
iso3c=="PRE"|iso3c=="PSS"|iso3c=="PST"|iso3c=="SAS"| iso3c=="SSA"|iso3c=="SSF"|iso3c=="SST"|iso3c=="TEA"| ///
iso3c=="TEC" |iso3c=="TLA"|iso3c=="TMN"|iso3c=="TSA"|iso3c=="TSS"|iso3c=="UMC"|iso3c=="WLD" 
*countries splitting / merging*
replace iso3c="CZS" if iso3c=="CZE" & year<=1990 /*income data on Czech republic before 1991 assigned to Czechoslovakia*/
replace iso3c="ETH1" if iso3c=="ETH" & year>=1981 & year<=1989 /* income data for Ethiopia from 1981 to 1989, assigned to ETH1 (Ethipia and Eriteria)*/
replace iso3c="GFR" if iso3c=="DEU" & year<=1990 /* income data for Germany available from 1960 to 1990, assigned to GFR. no income data for East Germany*/
replace iso3c="YUG" if iso3c=="SRB" & year<=1990 /*income data for Serbia available from 1991 to 2002 assigned to SCG (Serbia and Montenegro) */
replace iso3c="SCG" if iso3c=="SRB" & year>=1991 & year<=2002
replace iso3c="USSR" if iso3c=="RUS" & year<=1992 /*income data on Russia before 1993 assigned to USSR*/
replace iso3c="TOG" if iso3c=="TGO"
drop if year<=1961
drop if year>2019
foreach v of varlist exports imports fuelexports_share fuelimports_share metalexports_share metalimports_share {
replace `v' = 0 if `v'==.
}
**create variables**
*share in exports/imports*
gen resourcesexports_share= fuelexports_share + metalexports_share
label var resourcesexports_share "Natural resources exports (% of merchandise exports) (WDI)"
gen resourcesimports_share= fuelimports_share + metalimports_share
label var resourcesimports_share "Natural resources exports (% of merchandise imports) (WDI)"
*fuel and metal net exports in levels*
gen fuelexports= (fuelexports_share/100) * exports
label var fuelexports "Fuel exports (current US$) (WDI)"
gen metalexports= (metalexports_share/100) * exports
label var metalexports "Ores and metal exports (current US$) (WDI)"
gen fuelimports= (fuelimports_share/100) * imports
label var fuelimports "Fuel imports (current US$) (WDI)"
gen metalimports= (metalimports_share/100) * imports
label var metalimports "Ores and metal imports (current US$) (WDI)"
gen fuelnetexports= fuelexports - fuelimports
label var fuelnetexports "Fuel net exports (current US$) (WDI)"
gen metalnetexports= metalexports - metalimports
label var metalnetexports "Ores and metal net exports (current US$) (WDI)"
*net exports in levels*
gen resourcesexports= fuelexports + metalexports
label var resourcesexports "Natural resources exports (current US$) (WDI)"
gen resourcesimports= fuelimports + metalimports
label var resourcesimports "Natural resources imports (current US$) (WDI)"
gen resourcesnetexports= fuelnetexports + metalnetexports
label var resourcesnetexports "Natural resources net exports (current US$) (WDI)"
gen netexports=exports-imports
label var netexports "Merchandise net exports (current US$) (WDI)"
*resource net exports per worker*
gen resource_per_worker=resourcesnetexports/workingpop 
label var resource_per_worker "Ratio of natural resources net exports to working age population (WDI)"
*order and save*
order country iso3c year exports imports netexports fuelexports_share fuelexports fuelimports_share fuelimports fuelnetexports metalexports_share metalexports metalimports_share metalimports metalnetexports resourcesexports_share resourcesexports resourcesimports_share resourcesimports resourcesnetexports resource_per_worker
sort  iso3c  year 
save "$dir\data\resources/resources.dta", replace

***Merge All***			
**merge different data sets**
*merge unido and comtrade data*
use "$dir\data\unido\unido_2digit\diversification.dta",  clear
foreach v of varlist employment gini_emp hhi_emp value_added gini_va hhi_va {
rename `v' `v'_2digit
}
merge 1:1 iso3c year using "$dir\data\unido\unido_3digit\diversification.dta"
drop _merge
foreach v of varlist employment gini_emp hhi_emp value_added gini_va hhi_va {
rename `v' `v'_3digit
}
merge 1:1 iso3c year using "$dir\data\unido\unido_4digit\diversification.dta"
drop _merge
foreach v of varlist employment gini_emp hhi_emp value_added gini_va hhi_va {
rename `v' `v'_4digit
} 
merge 1:1 iso3c year using "$dir\data\comtrade\gini_comtrade.dta"
gen comtrade=0
replace comtrade=1 if _merge==2
drop _merge

*merge with data on income*
merge 1:1 iso3c year using "$dir\data\gdp\income.dta"
replace region="Europe & Central Asia" if iso3c=="GDR"
replace income_group="High income" if iso3c=="GDR"
replace developing=0 if iso3c=="GDR"
replace MENA=0 if iso3c=="GDR"
drop if _merge==2
drop _merge

*merge with data on natural resources *
merge 1:1 iso3c year using "$dir\data\resources\resources.dta"
drop if _merge==2
drop _merge
drop country

**create variables**
*resource abundant as net exporter*
bysort iso3c: egen resource_abundance=mean (resource_per_worker)
label var resource_abundance "Average ratio of natural resources net exports to working age population (WDI)"
gen resource_abundant=0
replace resource_abundant=1 if resource_abundance>0 & resource_abundance!=.
label var resource_abundant "Average net exporter of natural resources (WDI)"
gen fuel_per_worker= fuelnetexports/ workingpop
label var fuel_per_worker "Ratio of fuel net exports to working age population (WDI)"
bysort iso3c: egen fuel_abundance=mean (fuel_per_worker)
label var fuel_abundance "Average ratio of fuel net exports to working age population (WDI)"
gen fuel_abundant=0
replace fuel_abundant=1 if fuel_abundance>0 & fuel_abundance!=.
label var fuel_abundant "Average net exporter of fuel (WDI)"
gen metal_per_worker= metalnetexports/ workingpop
label var metal_per_worker "Ratio of ores and metal net exports to working age population (WDI)"
bysort iso3c: egen metal_abundance=mean (metal_per_worker)
label var metal_abundance "Average ratio of ores and metal net exports to working age population (WDI)"
gen metal_abundant=0
replace metal_abundant=1 if metal_abundance>0 & metal_abundance!=.
label var metal_abundant "Average net exporter of ores and metal (WDI)"
*highly vs moderately rich*
sum resource_abundance if resource_abundance>0 & resource_abundance!=., detail 
gen level_resource=0
replace level_resource=1 if resource_abundance>0 & resource_abundance<=280
replace level_resource=2 if resource_abundance>280 & resource_abundance!=.
label define level 0 "resource-poor" 1 "moderately resource-rich" 2"highly resource-rich"
label values level_resource level
label var level_resource "Level of resource endowment (WDI)"
*remove microstates and outliers (Cadot et al. 2011)*
egen mpop=mean(pop), by(iso3c)
keep if mpop>1000000
save "$dir\data/data_final.dta", replace

**Trade in services data 1980-2013**
import excel "$dir\data\services\BPM5\WtoData_20230525153023.xlsx", sheet("Report") cellrange(A3:AJ3134) firstrow clear
rename *, lower
split productsector, p(-)
gen productname2002 = productsector3
replace productname2002 = productsector3 + "-" + productsector4 if productsector4!=""
gen productcode2002=strtrim(productsector2)
drop productsector productsector1 productsector2 productsector3 productsector4 
rename reportingeconomy countryname
reshape long yr, i(countryname productname) j(year)
gen value= yr*1000000
label var value "Commercial services exports by sector – annual  (1980-2013)"
replace value=. if value<0 
kountry countryname, from(other) stuck 
rename _ISO3N_ iso3n
kountry iso3n, from(iso3n) to(iso3c)  
drop iso3n 
rename _ISO3C_ iso3c
tab countryname if iso3c==""
replace iso3c="ABW" if strpos(countryname,"Aruba")>0
replace iso3c="BHR" if strpos(countryname,"Bahrain, Kingdom of")>0
replace iso3c="BEX" if strpos(countryname,"Belgium-Luxembourg")>0
replace iso3c="BOL" if strpos(countryname,"Bolivia, Plurinational State of")>0
replace iso3c="CPV" if strpos(countryname,"Cabo Verde")>0
replace iso3c="CUW" if strpos(countryname,"Curaçao")>0
replace iso3c="CSK" if strpos(countryname,"Czech and Slovak Federal Republi")>0
replace iso3c="CIV" if strpos(countryname,"Côte d'Ivoire")>0
replace iso3c="SWZ" if strpos(countryname,"Eswatini")>0
replace iso3c="KWT" if strpos(countryname,"Kuwait, the State of")>0
replace iso3c="LBN" if strpos(countryname,"Lebanese Republic")>0
replace iso3c="MKD" if strpos(countryname,"North Macedonia")>0
replace iso3c="STP" if strpos(countryname,"Sao Tomé and Principe")>0
replace iso3c="SAU" if strpos(countryname,"Saudi Arabia, Kingdom of")>0
replace iso3c="SXM" if strpos(countryname,"Sint Maarten")>0
order countryname iso3c productname productcode year value 
*correspondance EBOPS 2002 to EBOPS 2010 (Wettstein et al. 2019 and Borchart et al 2020)*
gen productcodecombined=""
replace productcodecombined="SC" if productcode2002=="S205" | productcode2002=="S246"
replace productcodecombined="SDA+SDB3" if productcode2002=="S236" 
replace productcodecombined="SE" if productcode2002=="S249"
replace productcodecombined="SF" if productcode2002=="S253"
replace productcodecombined="SG" if productcode2002=="S260"
replace productcodecombined="SH" if productcode2002=="S266"
replace productcodecombined="SI+SK1" if productcode2002=="S247" | productcode2002=="S262" | productcode2002=="S288"
replace productcodecombined="SJ" if productcode2002=="S268" 
replace productcodecombined="SDB1+SK21 and SDB2+SK22" if productcode2002=="S289"
replace productcodecombined="SL" if productcode2002=="S291"
replace productcodecombined="SN" if productcode2002=="S982"
save "$dir\data\services\BPM5\servicetradebpm5.dta", replace

**Trade in services data 2005-2021**
import excel "$dir\data\services\BPM6\WtoData_20230525152753.xlsx", sheet("Report") cellrange(A3:T8239) firstrow clear
rename *, lower
split productsector, p(-)
gen productname2010 = productsector3
replace productname2010 = productsector3 + "-" + productsector4 if productsector4!=""
gen productcode2010=strtrim(productsector2)
drop productsector productsector1 productsector2 productsector3 productsector4 partnereconomy
rename reportingeconomy countryname
reshape long yr, i(countryname productname) j(year)
gen value= yr*1000000
label var value "Commercial services exports by sector – annual  (2005-2021)"
replace value=. if value<0 
kountry countryname, from(other) stuck 
rename _ISO3N_ iso3n
kountry iso3n, from(iso3n) to(iso3c)  
drop iso3n 
rename _ISO3C_ iso3c
tab countryname if iso3c==""
replace iso3c="ABW" if strpos(countryname,"Aruba")>0
replace iso3c="BHR" if strpos(countryname,"Bahrain, Kingdom of")>0
replace iso3c="BOL" if strpos(countryname,"Bolivia, Plurinational State of")>0
replace iso3c="CPV" if strpos(countryname,"Cabo Verde")>0
replace iso3c="CUW" if strpos(countryname,"Curaçao")>0
replace iso3c="CIV" if strpos(countryname,"Côte d'Ivoire")>0
replace iso3c="SWZ" if strpos(countryname,"Eswatini")>0
replace iso3c="KWT" if strpos(countryname,"Kuwait, the State of")>0
replace iso3c="LBN" if strpos(countryname,"Lebanese Republic")>0
replace iso3c="MKD" if strpos(countryname,"North Macedonia")>0
replace iso3c="STP" if strpos(countryname,"Sao Tomé and Principe")>0
replace iso3c="SAU" if strpos(countryname,"Saudi Arabia, Kingdom of")>0
replace iso3c="SXM" if strpos(countryname,"Sint Maarten")>0
replace iso3c="TUR" if strpos(countryname,"Türkiye")>0
replace iso3c="VEN" if strpos(countryname,"Venezuela, Bolivarian Republic of")>0
order countryname iso3c productname productcode year value
**correspondance EBOPS 2002 to EBOPS 2010 (Wettstein et al. 2019 and Borchart et al 2020)*
gen productcodecombined=""
replace productcodecombined="SA" if productcode2010=="SA"
replace productcodecombined="SB" if productcode2010=="SB"
replace productcodecombined="SC" if productcode2010=="SC"
replace productcodecombined="SDA+SDB3" if productcode2010=="SDA" | productcode2010=="SDB3" 
replace productcodecombined="SE" if productcode2010=="SE"
replace productcodecombined="SF" if productcode2010=="SF"
replace productcodecombined="SG" if productcode2010=="SG"
replace productcodecombined="SH" if productcode2010=="SH"
replace productcodecombined="SI+SK1" if productcode2010=="SI" | productcode2010=="SK1" 
replace productcodecombined="SJ" if productcode2010=="SJ"
replace productcodecombined="SDB1+SK21 and SDB2+SK22" if productcode2010=="SDB1" | productcode2010=="SK21" |productcode2010=="SDB2" | productcode2010=="SK22" 
replace productcodecombined="SL" if productcode2010=="SL"
replace productcodecombined="SN" if productcode2010=="SN"
save "$dir\data\services\BPM6\servicetradebpm6.dta", replace

**Append both datasets**
use  "$dir\data\services\BPM5\servicetradebpm5.dta",  clear
drop if year>=2005
drop if countryname=="Serbia and Montenegro" 
append using "$dir\data\services\BPM6\servicetradebpm6.dta"
drop if productcodecombined==""
*collapse dataset*
collapse (sum) value, by(iso3c productcodecombined year)
*make dataset balanced*
fillin iso3c year productcodecombined
replace value=0 if value==.
label var value "Commercial services exports by sector – annual  (2005-2021) (Million US dollar)"
label var productcodecombined "EBOPS2010 combined sectors"
codebook iso3c productcodecombined year value
gen isicrev31=""
replace isicrev31="I(60-64)" if productcodecombined=="SC"
replace isicrev31="H(55)" if productcodecombined=="SDA+SDB3"
replace isicrev31="F(45)" if productcodecombined=="SE"
replace isicrev31="J(65-67)" if productcodecombined=="SF"
replace isicrev31="J(65-67)" if productcodecombined=="SG"
replace isicrev31="K(70-74)" if productcodecombined=="SI+SK1"
replace isicrev31="K(70-74)" if productcodecombined=="SJ"
replace isicrev31="O(90-93)" if productcodecombined=="SK24"
replace isicrev31="O(90-93)" if productcodecombined=="SK23"
replace isicrev31="M(80) and N(85)" if productcodecombined=="SDB1+SK21 and SDB2+SK22"
**calculate gini and hhi**
drop isicrev31 _fillin
*calculate gini*
sort year iso3c value
bysort year iso3c: egen total=total(value)
drop if total==0 /*missing observations*/
by year iso3c: gen si= sum(value/total)
egen y = sum((si+si[_n-1])/13), by (year iso3c)
by year iso3c: gen gini= abs(1-y)
*calculate hhi*
by year iso3c: gen si2 = (value/total)^2
egen hhi_0 = sum(si2), by (year iso3c)
gen hhi= (hhi_0-(1/13)) / (1-(1/13))
collapse (sum) value (mean) gini hhi, by (iso3c year)
**add other variables**
drop if year>2019
*merge with data on income*
merge 1:1 iso3c year using "$dir\data\gdp\income.dta"
replace region="Europe & Central Asia" if iso3c=="GDR"
replace income_group="High income" if iso3c=="GDR"
replace developing=0 if iso3c=="GDR"
replace MENA=0 if iso3c=="GDR"
drop if _merge==2
drop _merge
*merge with data on natural resources *
merge 1:1 iso3c year using "$dir\data\resources\resources.dta"
drop if _merge==2
drop _merge
drop country
**create variables**
bysort iso3c: egen resource_abundance=mean (resource_per_worker)
label var resource_abundance "Average ratio of natural resources net exports to working age population (WDI)"
gen resource_abundant=0
replace resource_abundant=1 if resource_abundance>0 & resource_abundance!=.
label var resource_abundant "Average net exporter of natural resources (WDI)"
gen fuel_per_worker= fuelnetexports/ workingpop
label var fuel_per_worker "Ratio of fuel net exports to working age population (WDI)"
bysort iso3c: egen fuel_abundance=mean (fuel_per_worker)
label var fuel_abundance "Average ratio of fuel net exports to working age population (WDI)"
gen fuel_abundant=0
replace fuel_abundant=1 if fuel_abundance>0 & fuel_abundance!=.
label var fuel_abundant "Average net exporter of fuel (WDI)"
gen metal_per_worker= metalnetexports/ workingpop
label var metal_per_worker "Ratio of ores and metal net exports to working age population (WDI)"
bysort iso3c: egen metal_abundance=mean (metal_per_worker)
label var metal_abundance "Average ratio of ores and metal net exports to working age population (WDI)"
gen metal_abundant=0
replace metal_abundant=1 if metal_abundance>0 & metal_abundance!=.
label var metal_abundant "Average net exporter of ores and metal (WDI)"
*highly vs moderately rich*
sum resource_abundance if resource_abundance>0 & resource_abundance!=., detail 
gen level_resource=0
replace level_resource=1 if resource_abundance>0 & resource_abundance<=335
replace level_resource=2 if resource_abundance>335 & resource_abundance!=.
label define level 0 "resource-poor" 1 "moderately resource-rich" 2"highly resource-rich"
label values level_resource level
label var level_resource "Level of resource endowment (WDI)"
*remove microstates and outliers (Cadot et al. 2011)*
egen mpop=mean(pop), by(iso3c)
keep if mpop>1000000
save "$dir\data/services/tradeservices.dta", replace

*partition sample into S=796 subamples of size J=10,000$ with an overlap of delta=50$**
use "$dir/data/data_final.dta",  clear 
drop if gdppc_penn==. | gini_emp_2digit==.
keep iso3c year penn_to_85 gini_emp_2digit
append using "$dir/data/semiparametric/midpoint_10"
gen penn_to_85_000=penn_to_85/1000 /*gdp per capita expressed in 1000*/
*run fixed effects regression (xtreg) for each subsample, s*
encode iso3c, gen(iso3c1)
xtset iso3c1 year
matrix A=J(796, 9, 0)
local i=5250
while `i'<=45000 {
quietly xtreg gini_emp_2digit penn_to_85_000 if (penn_to_85>(`i'-5000) & penn_to_85<(`i'+5000)), fe
matrix B=e(b)
matrix V=e(V)
matrix Z=e(N)
quietly predict error if penn_to_85==`i', stdp
quietly summarize error
matrix A[(`i'/50)-(104),6]=r(mean)
drop error
quietly predict fitted if penn_to_85==`i', xb
quietly summarize fitted
matrix A[(`i'/50)-(104),1]=r(mean)
drop fitted
matrix inc=`i'
matrix A[(`i'/50)-(104),2]=B[1,1]/sqrt(V[1,1])
matrix A[(`i'/50)-(104),3]=B[1,2]/sqrt(V[2,2])
matrix A[(`i'/50)-(104),4]=inc[1,1]
matrix A[(`i'/50)-(104),5]=B[1,1]
matrix A[(`i'/50)-(104),7]=B[1,2]
matrix A[(`i'/50)-(104),8]=Z[1,1]
quietly count if (penn_to_85<(`i'+5000) & penn_to_85>=250 & year!=.)
matrix A[(`i'/50)-(104),9]=r(N)/4929
local i=`i'+50
}
drop if year!=.
drop iso3c year gini_emp_2digit penn_to_85 penn_to_85_000 iso3c1
svmat A, name(cgini) /*command creates variables from matrix*/
rename cgini1 fittedgini
label variable fittedgini "Fitted Gini Curve"
rename cgini2 t_gdp
label variable t_gdp "t-statistic on the estimated slope parameter"
rename cgini3 t_cons
label variable t_cons "t-statistic on the estimated intercept parameter"
rename cgini4 midpoint
label variable midpoint "Income Midpoint for Estimation"
rename cgini5 b_gdp
label variable b_gdp "Slope Estimate - Gini"
rename cgini7 b_cons
label variable b_cons "Intercept Estimate - Gini"
rename cgini6 stdegini
label variable stdegini "Standard Error of the Predicted Value - Gini"
gen lbgini=fittedgini-(1.96*stdegini)
label variable lbgini "95% Confidence Interval Lower Bound - Gini"
gen ubgini=fittedgini+(1.96*stdegini)
label variable ubgini "95% Confidence Interval Higher Bound - Gini"
rename cgini8 numobs
sum numobs /* Average number of observations per regression*/
rename cgini9 cumfreq
label variable cumfreq "Cumulative Frequency"
sort midpoint
save "$dir/data/semiparametric/semiparametric.dta", replace