***Descriptive Stats***
clear

**Figures and Tables**

*Figure 1*
use "$dir/data/data_final.dta",  clear 
sort iso3c year
gen growth = ((penn_to_85[_n]- penn_to_85[_n-1])/penn_to_85[_n-1]) if iso3c[_n]==iso3c[_n-1]
drop if year<1970
egen SD = sd(growth), by(iso3c)
drop if year!=1970
gen loggdp=log(penn_to_85)

twoway (lfit SD loggdp, lcolor(black) ) (scatter SD loggdp, jitter(7) mlabel(iso3c) mlabsize(*.5) mlabcolor(forest_green) mlabposition(6) mc(forest_green%50) msize(medium) xtitle("GDP per capita in 1970, log", size(small)) ytitle("Standard deviation of GDP growth from 1970 to 2019", size(small)) graphregion(m(medsmall) c(white))  legend(off)  saving("$dir/figures and tables/figure1a.gph", replace))

twoway (lfit SD gini_exp_2, lcolor(black) ) (scatter SD gini_exp_2, jitter(7) mlabel(iso3c) mlabsize(*.5) mlabcolor(forest_green) mlabposition(6) mc(forest_green%50) msize(medium) xtitle("Gini of exports in 1970", size(small)) ytitle("Standard deviation of GDP growth from 1970 to 2019", size(small)) graphregion(m(medsmall) c(white)) legend(off) saving("$dir/figures and tables/figure1b.gph", replace))

graph combine "$dir/figures and tables/figure1a.gph" "$dir/figures and tables/figure1b.gph", ycommon graphregion(m(medsmall) c(white)) saving("$dir/figures and tables/figure1.gph", replace)


*Figure 2*
use "$dir/data/data_final.dta",  clear 
drop if gdppc_penn>100000

twoway (lowess gini_emp_2digit penn_to_85, lwidth(medthick) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) xline(20000, lcolor(black) lpattern(dash)) ytitle("Gini", size(small)) legend(off) graphregion(m(medsmall) c(white))title("Employment", size(medsmall)) saving("$dir/figures and tables/figure2a.gph", replace))

twoway (lowess gini_va_2digit penn_to_85, lwidth(medthick) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) xline(20000, lcolor(black) lpattern(dash)) ytitle("Gini", size(small)) legend(off) graphregion(m(medsmall) c(white))title("Value-added", size(medsmall)) saving("$dir/figures and tables/figure2b.gph", replace)) 

twoway (lowess gini_exp_2 penn_to_85, lwidth(medthick)  ylabel(0.5(0.1)1) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) xline(20000, lcolor(black) lpattern(dash)) ytitle("Gini", size(small))  legend(off) graphregion(m(medsmall) c(white))title("Exports", size(medsmall)) saving("$dir/figures and tables/figure2c.gph", replace)) 

graph combine "$dir/figures and tables/figure2a.gph"  "$dir/figures and tables/figure2b.gph" "$dir/figures and tables/figure2c.gph", ycommon xcommon col(3) graphregion(m(medsmall) c(white)) title("Lowess curve for Gini of employment, value added and exports against GDP per capita (PPP) at 2-digit level", size(small)) saving("$dir/figures and tables/figure2.gph", replace)


*Figure 3*
use "$dir/data/services/tradeservices.dta", clear
drop if gdppc_penn>100000

twoway (lowess gini penn_to_85, lwidth(medthick) xtitle("GDP per capita, PPP (constant 1985)", size(small)) xline(25800, lcolor(black) lpattern(dash)) ytitle("Gini", size(small)) legend(off) graphregion(m(medsmall) c(white))title("Services Exports", size(medsmall)) saving("$dir/figures and tables/figure3.gph", replace)) 


*Figure 4*
use "$dir/data/data_final.dta",  clear 
drop if gdppc_penn>100000
bysort iso3c: egen average_gini=mean(gini_emp_2digit)
gen demean_gini=gini_emp_2digit-average_gini
bysort iso3c: egen average_gdp=mean(penn_to_85)
gen demean_gdp=penn_to_85-average_gdp
replace demean_gini=. if iso3c=="NAM"| iso3c=="CZS" | iso3c=="USSR"
replace demean_gdp=. if iso3c=="YUG"| iso3c=="CZS" | iso3c=="USSR"

twoway (lowess gini_emp_2digit penn_to_85 , lstyle(foreground) lcolor(navy) lwidth(medthick) title("Pooled (N=4,932)", size(medium)) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) ytitle("Gini", size(small)) graphregion(m(medsmall) c(white)) legend(off) saving("$dir/figures and tables/figure4a.gph", replace))   

twoway (lowess demean_gini demean_gdp , lstyle(foreground) lcolor(navy) lwidth(medthick) title("Within (N=4,929)", size(medium)) xlabel(, angle(45)) xtitle("Change in GDP per capita, PPP (constant 1985)", size(small)) ytitle("Change in Gini", size(small)) legend(off) graphregion(m(medsmall) c(white))   saving("$dir/figures and tables/figure4c.gph", replace))   

use "$dir/data/data_final.dta",  clear 
drop if gdppc_penn>100000
collapse (mean)gini_emp_2digit (mean) penn_to_85, by (iso3c)
rename gini_emp_2digit average_gini
rename penn_to_85 average_gdp

twoway (lowess average_gini average_gdp, lstyle(foreground) lcolor(navy) lwidth(medthick) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) ytitle("Gini", size(medsmall))  legend(off) title("Between (N=140)", size(medium)) graphregion(m(medsmall) c(white)) saving("$dir/figures and tables/figure4b.gph", replace))

*combine 3 graphs*
graph combine "$dir/figures and tables/figure4a.gph" "$dir/figures and tables/figure4b.gph" "$dir/figures and tables/figure4c.gph",  rows(1) graphregion(m(medsmall) c(white))  title(Employment (2-digit) and GDP per capita (PPP) for all countries, size(* .55)) saving("$dir/figures and tables/figure4.gph", replace)  

*Table 1*
use "$dir/data/data_final.dta",  clear 
encode iso3c, gen(iso3c1)
xtset iso3c1 year
replace penn_to_85=penn_to_85/1000
gen penn_to_85_sq=penn_to_85*penn_to_85
label var gini_emp_2digit "Gini Index"
label var penn_to_85 "GDP per capita"
label var penn_to_85_sq "GDP per capita square"

xtreg gini_emp_2digit penn_to_85, fe
ssc install outreg2
outreg2 using "$dir/figures and tables/table1.doc", replace ctitle(All - Linear) label dec(5)
xtreg gini_emp_2digit penn_to_85 penn_to_85_sq, fe
outreg2 using "$dir/figures and tables/table1.doc", append ctitle(All - Quadratic) label dec(5)
xtreg gini_emp_2digit penn_to_85 if resource_abundant==0, fe 
outreg2 using "$dir/figures and tables/table1.doc", append ctitle(Resource-Poor - Linear) label dec(5)
xtreg gini_emp_2digit penn_to_85 penn_to_85_sq if resource_abundant==0, fe 
outreg2 using "$dir/figures and tables/table1.doc", append ctitle(Resource-Poor - Quadratic) label dec(5)
xtreg gini_emp_2digit penn_to_85 if resource_abundant==1, fe
outreg2 using "$dir/figures and tables/table1.doc", append ctitle(Resource-Rich - Linear) label dec(5)
xtreg gini_emp_2digit penn_to_85 penn_to_85_sq if resource_abundant==1, fe
outreg2 using "$dir/figures and tables/table1.doc", append ctitle(Resource-Rich - Quadratic) label dec(5)

**Table 2**
xtreg gini_emp_2digit penn_to_85 i.year, be 
outreg2 using "$dir/figures and tables/table2.doc", keep(gini_emp_2digit penn_to_85 penn_to_85_sq) replace ctitle(All - Linear) label dec(5)
xtreg gini_emp_2digit penn_to_85 penn_to_85_sq i.year, be 
outreg2 using "$dir/figures and tables/table2.doc", keep(gini_emp_2digit penn_to_85 penn_to_85_sq) append ctitle(All - Quadratic) label dec(5)
xtreg gini_emp_2digit penn_to_85 i.year if resource_abundant==0, be 
outreg2 using "$dir/figures and tables/table2.doc", keep(gini_emp_2digit penn_to_85 penn_to_85_sq) append ctitle(Resource-Poor - Linear) label dec(5)
xtreg gini_emp_2digit penn_to_85 penn_to_85_sq i.year if resource_abundant==0, be 
outreg2 using "$dir/figures and tables/table2.doc", keep(gini_emp_2digit penn_to_85 penn_to_85_sq)  append ctitle(Resource-Poor - Quadratic) label dec(5)
xtreg gini_emp_2digit penn_to_85 i.year if resource_abundant==1, be 
outreg2 using "$dir/figures and tables/table2.doc", keep(gini_emp_2digit penn_to_85 penn_to_85_sq)  append ctitle(Resource-Rich - Linear) label dec(5)
xtreg gini_emp_2digit penn_to_85 penn_to_85_sq i.year if resource_abundant==1, be 
outreg2 using "$dir/figures and tables/table2.doc", keep(gini_emp_2digit penn_to_85 penn_to_85_sq)  append ctitle(Resource-Rich - Quadratic) label dec(5)


*Figure 5*
use "$dir/data/semiparametric/semiparametric.dta", clear

twoway (line fittedgini midpoint, lcolor(black) xlabel(5250(5000)50250, labsize(small) angle(45)) xtitle("Income midpoint", size(small)) ytitle("Gini", size(small)) legend(off) graphregion(m(medsmall) c(white)) title("Estimated Non-Parametric Curve For Gini - UNIDO 2-digit Employment Data", size(medsmall))) (line lbgini midpoint, lcolor(blue) lpattern(dash)) (line ubgini midpoint, lcolor(blue) lpattern(dash) saving("$dir/figures and tables/figure5.gph", replace))


*Figure 6*
twoway (line b_gdp midpoint, lcolor(black%50) xtitle("Income Midpoints", size(medsmall)) xlabel(5250(5000)50250, labsize(small) angle(45))  ylabel(-0.01(0.005)0.01, ) yline(0, lcolor(black%50) lpattern(dash)) ytitle("Slope Estimate", size(medsmall)) legend(off) graphregion(m(medsmall) c(white)) title("GDP Slope Estimates and Number of Observations", size(medsmall))) (scatter b_gdp midpoint if abs(t_gdp)> 1.96, mcolor(black) msize(small) msymbol(x)) (line numobs midpoint, lcolor(blue) yaxis(2) ytitle("Number of Observations", axis(2) size(medsmall)) saving("$dir/figures and tables/figure6.gph",replace)) 

*Figure 7*
twoway (line b_cons midpoint, lcolor(black%50) xlabel(5250(5000)50250, labsize(small) angle(45)) xtitle("Income midpoint", size(small)) ytitle("Intercept", size(small)) legend(off) graphregion(m(medsmall) c(white)) title("Intercept Estimates For Gini - UNIDO 2-digit Employment Data", size(medsmall))) (scatter b_cons midpoint if abs(t_cons)> 1.96, mcolor(black) msize(small) msymbol(x) saving("$dir/figures and tables/figure7.gph", replace))


*Figure 8*
use "$dir/data/data_final.dta",  clear 
drop if gdppc_penn>100000

twoway (lowess gini_emp_2digit penn_to_85 if resource_abundant==1,  lwidth(medthick) lcolor(navy)) (lowess gini_emp_2digit penn_to_85 if resource_abundant==0, lpattern(dash) lwidth(medthick) lcolor(navy) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) xline(20000, lcolor(black) lpattern(dash)) ytitle("Gini", size(small))  legend(label (1 "Resource-Rich") label(2 "Resource-Poor") size(small)) graphregion(m(medsmall) c(white))title("Employment", size(medsmall))  saving("$dir/figures and tables/figure8a.gph", replace))  

twoway (lowess gini_va_2digit penn_to_85 if resource_abundant==1,  lwidth(medthick) lcolor(navy)) (lowess gini_va_2digit penn_to_85 if resource_abundant==0, lpattern(dash) lwidth(medthick) lcolor(navy) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) xline(20000, lcolor(black) lpattern(dash)) ytitle("Gini", size(small)) legend(label (1 "Resource-Rich") label(2 "Resource-Poor") size(small)) graphregion(m(medsmall) c(white))title("Value-added", size(medsmall))  saving("$dir/figures and tables/figure8b.gph", replace))  

twoway (lowess gini_exp_2 penn_to_85 if resource_abundant==1,  lwidth(medthick) lcolor(navy)) (lowess gini_exp_2 penn_to_85 if resource_abundant==0, lpattern(dash) lwidth(medthick) lcolor(navy) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) xline(20000, lcolor(black) lpattern(dash)) ytitle("Gini", size(small)) legend(label (1 "Resource-Rich") label(2 "Resource-Poor") size(small)) graphregion(m(medsmall) c(white))title("Exports", size(medsmall))  saving("$dir/figures and tables/figure8c.gph", replace))  

grc1leg2 "$dir/figures and tables/figure8a.gph"  "$dir/figures and tables/figure8b.gph" "$dir/figures and tables/figure8c.gph" , ycommon xcommon graphregion(m(medsmall) c(white)) col(3) title("Lowess curve for Gini of employment, value added and exports against GDP per capita (PPP) at 2-digit level", size(small)) saving("$dir/figures and tables/figure8.gph" , replace)


*Table A5*
use "$dir/data/data_final.dta",  clear 
estpost sum employment_2digit gini_emp_2digit hhi_emp_2digit value_added_2digit gini_va_2digit hhi_va_2digit
eststo mysummaries
esttab using "$dir/figures and tables/table A5.doc",  replace cells("count(fmt(0)) mean(fmt(2)) sd(fmt(2)) min(fmt(2)) max(fmt(2))") noobs nostar nonumbers

*Table A6*
use "$dir/data/data_final.dta",  clear
label define resource_abundant 1 "Resource-Rich" 0 "Resource-Poor"
label values resource_abundant resource_abundant 
label define level 1 "Moderately Resource-Rich" 2 "Highly Resource-Rich", modify
label values level_resource level

egen tag = tag(iso3c resource_abundant)
egen ndistinct_resourceabundant = total(tag), by(resource_abundant)
drop tag
egen tag = tag(iso3c level_resource)
egen ndistinct_resourcelevel = total(tag), by(level_resource)
drop tag

estpost sum ndistinct_resourceabundant if resource_abundant==0, detail
eststo mysummaries
esttab using "$dir/figures and tables/table A6.doc", replace cells("mean(fmt(2))") noobs nostar nonumbers label

estpost sum penn_to_85 if resource_abundant==0, detail
eststo mysummaries
esttab using "$dir/figures and tables/table A6.doc", append cells("mean(fmt(2)) p50(fmt(2)) min(fmt(2)) max(fmt(2))") noobs nostar nonumbers label

estpost sum ndistinct_resourceabundant if resource_abundant==1, detail
eststo mysummaries
esttab using "$dir/figures and tables/table A6.doc", append cells("mean(fmt(2))") noobs nostar nonumbers label

estpost sum penn_to_85 if resource_abundant==1, detail
eststo mysummaries
esttab using "$dir/figures and tables/table A6.doc",  append cells("mean(fmt(2)) p50(fmt(2)) min(fmt(2)) max(fmt(2))") noobs nostar nonumbers label

estpost sum ndistinct_resourcelevel if level_resource==1, detail
eststo mysummaries
esttab using "$dir/figures and tables/table A6.doc", append cells("mean(fmt(2))") noobs nostar nonumbers label

estpost sum penn_to_85 if level_resource==1, detail
eststo mysummaries
esttab using "$dir/figures and tables/table A6.doc",  append cells("mean(fmt(2)) p50(fmt(2)) min(fmt(2)) max(fmt(2))") noobs nostar nonumbers label

estpost sum ndistinct_resourcelevel if level_resource==2, detail
eststo mysummaries
esttab using "$dir/figures and tables/table A6.doc", append cells("mean(fmt(2))") noobs nostar nonumbers label

estpost sum penn_to_85 if level_resource==2, detail
eststo mysummaries
esttab using "$dir/figures and tables/table A6.doc",  append cells("mean(fmt(2)) p50(fmt(2)) min(fmt(2)) max(fmt(2))") noobs nostar nonumbers label

*Table A7*
use "$dir/data/data_final.dta",  clear 

label define resource_abundant 1 "Resource-Rich" 0 "Resource-Poor"
label values resource_abundant resource_abundant 

egen tag = tag(iso3c resource_abundant)
egen ndistinct_resourceabundant = total(tag), by(resource_abundant)
drop tag

estpost sum ndistinct_resourceabundant if resource_abundant==0, detail
eststo mysummaries
esttab using "$dir/figures and tables/table A7.doc", replace cells("mean(fmt(2))") noobs nostar nonumbers label

bysort iso3c: egen countyear=count(year)
estpost sum countyear gini_emp_2digit gini_va_2digit if resource_abundant==0, detail
eststo mysummaries
esttab using "$dir/figures and tables/table A7.doc", append cells("mean(fmt(2)) sd(fmt(2)) min(fmt(2)) max(fmt(2))") noobs nostar nonumbers label

estpost sum ndistinct_resourceabundant if resource_abundant==1, detail
eststo mysummaries
esttab using "$dir/figures and tables/table A7.doc", append cells("mean(fmt(2))") noobs nostar nonumbers label

estpost sum countyear gini_emp_2digit gini_va_2digit if resource_abundant==1, detail
eststo mysummaries
esttab using "$dir/figures and tables/table A7.doc",  append cells("mean(fmt(2)) sd(fmt(2)) min(fmt(2)) max(fmt(2))") noobs nostar nonumbers label


*Figure A1*
use "$dir/data/data_final.dta",  clear 
keep if comtrade==0
tab iso3c, sort 
collapse (count)year (mean) penn_to_85 (max) MENA resource_abundant, by (iso3c)
gen year_mena_rr=.
replace year_mena_rr=year if  MENA==1  & resource_abundant==1 
gen year_other_rr=.
replace year_other_rr=year if  MENA==0  & resource_abundant==1 
gen year_other=.
replace year_other=year if resource_abundant==0 
tab iso3c if penn_to_85==. /*10 countries without gdp per capita data*/
sort penn_to_85
gen log_gdppc=log(penn_to_85)
twoway (scatter year_other year_mena_rr year_other_rr log_gdppc, jitter(7) mlabel(iso3c iso3c iso3c) mlabsize(*.5 *.5 *.5) mlabcolor(forest_green red blue) mlabposition(12 9 6) mc(forest_green%50 red%50 blue%50)  msize(medium) xlabel(,labsize(small))  xtitle("Log GDP per capita, PPP (constant 1985)", size(small)) ytitle("Number of Observations by Country", size(small)) graphregion(m(medsmall) c(white))) (lfit year log_gdppc , lcolor(black) title("Correlation Between income per capita and Data availability", size(medium))legend( order(1 "Resource-Poor" 2 "MENA - Resource-Rich" 3 "Other - Resource-Rich") col(3) size(vsmall)) saving("$dir/figures and tables/figureA1.gph" , replace))   

*Figure A2*
use "$dir/data/data_final.dta",  clear 
drop if gdppc_penn>100000

twoway (lowess hhi_emp_2digit penn_to_85, lwidth(medthick) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) xline(20000, lcolor(black) lpattern(dash)) ytitle("HHI", size(small)) legend(off) graphregion(m(medsmall) c(white))title("Employment", size(medsmall)) saving("$dir/figures and tables/figureA2a.gph", replace))

twoway (lowess hhi_va_2digit penn_to_85, lwidth(medthick) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) xline(20000, lcolor(black) lpattern(dash)) ytitle("HHI", size(small)) legend(off) graphregion(m(medsmall) c(white))title("Value-added", size(medsmall)) saving("$dir/figures and tables/figureA2b.gph", replace)) 

twoway (lowess hhi_exp_2 penn_to_85, lwidth(medthick) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) xline(20000, lcolor(black) lpattern(dash)) ytitle("HHI", size(small)) legend(off) graphregion(m(medsmall) c(white))title("Exports", size(medsmall)) saving("$dir/figures and tables/figureA2c.gph", replace)) 

graph combine "$dir/figures and tables/figureA2a.gph"  "$dir/figures and tables/figureA2b.gph" "$dir/figures and tables/figureA2c.gph", ycommon xcommon col(3) graphregion(m(medsmall) c(white)) title("Lowess curve for HHI of employment, value added and exports against GDP per capita (PPP) at 2-digit level", size(small)) saving("$dir/figures and tables/figureA2.gph", replace)

*Figure A3*
use "$dir/data/data_final.dta",  clear 
drop if gdppc_penn>100000

twoway (lowess gini_emp_2digit penn_to_85, lcolor(dknavy) lwidth(medthick) legend(label(1 "Lowess 2-digit") label(2 "Lowess 3-digit") label(3 "Lowess 4-digit" )) xlabel(, angle(45))) (lowess gini_emp_3digit penn_to_85, lcolor(maroon) lwidth(medthick) xlabel(, angle(45))) (lowess gini_emp_4digit penn_to_85, lcolor(forest_green) lwidth(medthick) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) ytitle("Gini", size(small)) graphregion(m(medsmall) c(white))title("Employment", size(medsmall)) saving("$dir/figures and tables/figureA3a.gph", replace))

twoway (lowess gini_va_2digit penn_to_85, lcolor(dknavy) lwidth(medthick) legend(off) xlabel(, angle(45))) (lowess gini_va_3digit penn_to_85, lcolor(maroon) lwidth(medthick) xlabel(, angle(45))) (lowess gini_va_4digit penn_to_85, lcolor(forest_green) lwidth(medthick) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) ytitle("Gini", size(small)) graphregion(m(medsmall) c(white))title("Value-added", size(medsmall)) saving("$dir/figures and tables/figureA3b.gph", replace)) 

twoway (lowess gini_exp_2 penn_to_85, lcolor(dknavy legend(off)) lwidth(medthick) xlabel(, angle(45))) (lowess gini_exp_4 penn_to_85, lcolor(forest_green) lwidth(medthick) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) ytitle("Gini", size(small)) graphregion(m(medsmall) c(white))title("Exports", size(medsmall)) saving("$dir/figures and tables/figureA3c.gph", replace))

grc1leg2 "$dir/figures and tables/figureA3a.gph" "$dir/figures and tables/figureA3b.gph" "$dir/figures and tables/figureA3c.gph" , ycommon xcommon col(3) graphregion(m(medsmall) c(white)) title("Lowess curve for Gini of employment, value added and exports against GDP per capita (PPP) for All countries", size(small)) saving("$dir/figures and tables/figureA3.gph", replace)

*Figure A4*
use "$dir/data/data_final.dta",  clear 
drop if gdppc_penn>100000

twoway (lowess hhi_emp_2digit penn_to_85, lcolor(dknavy) lwidth(medthick) legend(label(1 "Lowess 2-digit") label(2 "Lowess 3-digit") label(3 "Lowess 4-digit" )) xlabel(, angle(45))) (lowess hhi_emp_3digit penn_to_85, lcolor(maroon) lwidth(medthick) xlabel(, angle(45))) (lowess hhi_emp_4digit penn_to_85, lcolor(forest_green) lwidth(medthick) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) ytitle("HHI", size(small)) graphregion(m(medsmall) c(white))title("Employment", size(medsmall)) saving("$dir/figures and tables/figureA4a.gph", replace)) 

twoway (lowess hhi_va_2digit penn_to_85, lcolor(dknavy) lwidth(medthick) legend(off) xlabel(, angle(45))) (lowess hhi_va_3digit penn_to_85, lcolor(maroon) lwidth(medthick) xlabel(, angle(45))) (lowess hhi_va_4digit penn_to_85, lcolor(forest_green) lwidth(medthick) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) ytitle("HHI", size(small)) graphregion(m(medsmall) c(white))title("Value-added", size(medsmall)) saving("$dir/figures and tables/figureA4b.gph", replace)) 

twoway (lowess hhi_exp_2 penn_to_85, lcolor(dknavy legend(off)) lwidth(medthick) xlabel(, angle(45))) (lowess hhi_exp_4 penn_to_85, lcolor(forest_green) lwidth(medthick) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) ytitle("HHI", size(small)) graphregion(m(medsmall) c(white))title("Exports", size(medsmall)) saving("$dir/figures and tables/figureA4c.gph", replace))

grc1leg2 "$dir/figures and tables/figureA4a.gph" "$dir/figures and tables/figureA4b.gph" "$dir/figures and tables/figureA4c.gph" , ycommon xcommon col(3) graphregion(m(medsmall) c(white)) title("Lowess curve for HHI of employment, value added and exports against GDP per capita (PPP) for All countries", size(small)) saving("$dir/figures and tables/figureA4.gph", replace)


*Figure A5*
use "$dir/data/data_final.dta",  clear 
drop if gdppc_penn>100000
bysort iso3c: egen average_gini=mean(gini_va_2digit)
gen demean_gini=gini_va_2digit-average_gini
bysort iso3c: egen average_gdp=mean(penn_to_85)
gen demean_gdp=penn_to_85-average_gdp
replace demean_gini=. if iso3c=="NAM"| iso3c=="CZS" | iso3c=="USSR"
replace demean_gdp=. if iso3c=="YUG"| iso3c=="CZS" | iso3c=="USSR"

twoway (lowess gini_va_2digit penn_to_85 , lstyle(foreground) lcolor(navy) lwidth(medthick) title("Pooled (N=4,650)", size(medium)) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) ytitle("Gini", size(small)) graphregion(m(medsmall) c(white)) legend(off) saving("$dir/figures and tables/figureA5a.gph", replace))   

twoway (lowess demean_gini demean_gdp , lstyle(foreground) lcolor(navy) lwidth(medthick) title("Within (N=4,649)", size(medium)) xlabel(, angle(45)) xtitle("Change in GDP per capita, PPP (constant 1985)", size(small)) ytitle("Change in Gini", size(small)) legend(off) graphregion(m(medsmall) c(white))   saving("$dir/figures and tables/figureA5c.gph", replace))   

use "$dir/data/data_final.dta",  clear 
drop if gdppc_penn>100000
collapse (mean)gini_va_2digit (mean) penn_to_85, by (iso3c)
rename gini_va_2digit average_gini
rename penn_to_85 average_gdp

twoway (lowess average_gini average_gdp, lstyle(foreground) lcolor(navy) lwidth(medthick) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) ytitle("Gini", size(medsmall))  legend(off) title("Between (N=135)", size(medium)) graphregion(m(medsmall) c(white)) saving("$dir/figures and tables/figureA5b.gph", replace))

*combine 3 graphs*
graph combine "$dir/figures and tables/figureA5a.gph" "$dir/figures and tables/figureA5b.gph" "$dir/figures and tables/figureA5c.gph",  rows(1) graphregion(m(medsmall) c(white))  title(Value-added (2-digit) and GDP per capita (PPP) for all countries, size(* .55)) saving("$dir/figures and tables/figureA5.gph", replace)  

*Figure A6*
use "$dir/data/data_final.dta",  clear 
drop if gdppc_penn>100000
bysort iso3c: egen average_gini=mean(gini_exp_2)
gen demean_gini=gini_exp_2-average_gini
bysort iso3c: egen average_gdp=mean(penn_to_85)
gen demean_gdp=penn_to_85-average_gdp
replace demean_gini=. if iso3c=="NAM"| iso3c=="CZS" | iso3c=="USSR"
replace demean_gdp=. if iso3c=="YUG"| iso3c=="CZS" | iso3c=="USSR"

twoway (lowess gini_exp_2 penn_to_85 , lstyle(foreground) lcolor(navy) lwidth(medthick) title("Pooled (N=5,706)", size(medium)) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) ytitle("Gini", size(small)) graphregion(m(medsmall) c(white)) legend(off) saving("$dir/figures and tables/figureA6a.gph", replace))   

twoway (lowess demean_gini demean_gdp , lstyle(foreground) lcolor(navy) lwidth(medthick) title("Within (N=5,685)", size(medium)) xlabel(, angle(45)) xtitle("Change in GDP per capita, PPP (constant 1985)", size(small)) ytitle("Change in Gini", size(small)) legend(off) graphregion(m(medsmall) c(white))   saving("$dir/figures and tables/figureA6c.gph", replace))   

use "$dir/data/data_final.dta",  clear 
drop if gdppc_penn>100000
collapse (mean)gini_exp_2 (mean) penn_to_85, by (iso3c)
rename gini_exp_2 average_gini
rename penn_to_85 average_gdp

twoway (lowess average_gini average_gdp, lstyle(foreground) lcolor(navy) lwidth(medthick) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) ytitle("Gini", size(medsmall))  legend(off) title("Between (N=148)", size(medium)) graphregion(m(medsmall) c(white)) saving("$dir/figures and tables/figureA6b.gph", replace))

*combine 3 graphs*
graph combine "$dir/figures and tables/figureA6a.gph" "$dir/figures and tables/figureA6b.gph" "$dir/figures and tables/figureA6c.gph",  rows(1) graphregion(m(medsmall) c(white))  title(Exports (2-digit) and GDP per capita (PPP) for all countries, size(* .55)) saving("$dir/figures and tables/figureA6.gph", replace)  

*Figure A7*
use "$dir/data/data_final.dta",  clear 
drop if gdppc_penn>100000
bysort iso3c: egen average_gini=mean(gini_emp_2digit)
gen demean_gini=gini_emp_2digit-average_gini
bysort iso3c: egen average_gdp=mean(penn_to_85)
gen demean_gdp=penn_to_85-average_gdp
replace demean_gini=. if iso3c=="NAM"| iso3c=="CZS" | iso3c=="USSR"
replace demean_gdp=. if iso3c=="YUG"| iso3c=="CZS" | iso3c=="USSR"
keep if resource_abundant==1

twoway (lowess gini_emp_2digit penn_to_85 , lstyle(foreground) lcolor(navy) lwidth(medthick) title("Pooled (N=1,539)", size(medium)) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) ytitle("Gini", size(small)) graphregion(m(medsmall) c(white)) legend(off) saving("$dir/figures and tables/figureA7a.gph", replace))   

twoway (lowess demean_gini demean_gdp , lstyle(foreground) lcolor(navy) lwidth(medthick) title("Within (N=1,539)", size(medium)) xlabel(, angle(45)) xtitle("Change in GDP per capita, PPP (constant 1985)", size(small)) ytitle("Change in Gini", size(small)) legend(off) graphregion(m(medsmall) c(white)) saving("$dir/figures and tables/figureA7c.gph", replace))   

use "$dir/data/data_final.dta",  clear 
drop if gdppc_penn>100000
keep if resource_abundant==1
collapse (mean)gini_emp_2digit (mean) penn_to_85, by (iso3c)
rename gini_emp_2digit average_gini
rename penn_to_85 average_gdp
sum average_gini average_gdp

twoway (lowess average_gini average_gdp, lstyle(foreground) lcolor(navy) lwidth(medthick) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) ytitle("Gini", size(medsmall))  legend(off) title("Between (N=47)", size(medium)) graphregion(m(medsmall) c(white)) saving("$dir/figures and tables/figureA7b.gph", replace))

*combine 3 graphs*
graph combine "$dir/figures and tables/figureA7a.gph" "$dir/figures and tables/figureA7b.gph" "$dir/figures and tables/figureA7c.gph",  rows(1) graphregion(m(medsmall) c(white))  title(Employment (2-digit) and GDP per capita (PPP) for resource rich countries, size(* .55)) saving("$dir/figures and tables/figureA7.gph", replace)  

*Figure A8*
use "$dir/data/data_final.dta",  clear 
drop if gdppc_penn>100000
bysort iso3c: egen average_gini=mean(gini_emp_2digit)
gen demean_gini=gini_emp_2digit-average_gini
bysort iso3c: egen average_gdp=mean(penn_to_85)
gen demean_gdp=penn_to_85-average_gdp
replace demean_gini=. if iso3c=="NAM"| iso3c=="CZS" | iso3c=="USSR"
replace demean_gdp=. if iso3c=="YUG"| iso3c=="CZS" | iso3c=="USSR"
keep if resource_abundant==0

twoway (lowess gini_emp_2digit penn_to_85 , lstyle(foreground) lcolor(navy) lwidth(medthick) title("Pooled (N=3,393)", size(medium)) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) ytitle("Gini", size(small)) graphregion(m(medsmall) c(white)) legend(off) saving("$dir/figures and tables/figureA8a.gph", replace))   

twoway (lowess demean_gini demean_gdp , lstyle(foreground) lcolor(navy) lwidth(medthick) title("Within (N=3,390)", size(medium)) xlabel(, angle(45)) xtitle("Change in GDP per capita, PPP (constant 1985)", size(small)) ytitle("Change in Gini", size(small)) legend(off) graphregion(m(medsmall) c(white)) saving("$dir/figures and tables/figureA8c.gph", replace))   

use "$dir/data/data_final.dta",  clear 
drop if gdppc_penn>100000
keep if resource_abundant==0
collapse (mean)gini_emp_2digit (mean) penn_to_85, by (iso3c)
rename gini_emp_2digit average_gini
rename penn_to_85 average_gdp
sum average_gini average_gdp

twoway (lowess average_gini average_gdp, lstyle(foreground) lcolor(navy) lwidth(medthick) xlabel(, angle(45)) xtitle("GDP per capita, PPP (constant 1985)", size(small)) ytitle("Gini", size(medsmall))  legend(off) title("Between (N=93)", size(medium)) graphregion(m(medsmall) c(white)) saving("$dir/figures and tables/figureA8b.gph", replace))

*combine 3 graphs*
graph combine "$dir/figures and tables/figureA8a.gph" "$dir/figures and tables/figureA8b.gph" "$dir/figures and tables/figureA8c.gph",  rows(1) graphregion(m(medsmall) c(white))  title(Employment (2-digit) and GDP per capita (PPP) for resource poor countries, size(* .55)) saving("$dir/figures and tables/figureA8.gph", replace)

